@@ -70,13 +70,14 @@ public:
 
     bool reverse_lookups;
     bool force_quick_search;
-    int bypass_mode;
+    int bypass_mode = 0;
     bool bypass_v2 = false;
     bool cgi_bypass_v2 = false;
-    int bypass_version = 1;
+    int bypass_version = 2;
     bool cgi_bypass = false;
     int infection_bypass_mode;
     bool cgi_infection_bypass = false;
+    bool scan_bypass = false;
 
     std::string name;
     std::string magic;
@@ -115,6 +116,7 @@ public:
     // search term blocking
     unsigned int searchterm_list;
     bool searchterm_flag = false;
+    bool read_errors = false;
 
     FOptionContainer()
             :  searchterm_flag(false), banned_page(NULL)
@@ -122,7 +124,7 @@ public:
 
     ~FOptionContainer();
     bool read(const char *filename);
-    bool readConfFile(const char *filename);
+    bool readConfFile(const char *filename, String &list_pwd);
     void reset();
     void resetJustListData();
 
@@ -139,6 +141,7 @@ public:
     // get HTML template for this group
     HTMLTemplate *getHTMLTemplate(bool upfail);
     std::deque<std::string> text_mime;
+    std::deque<std::string> text_mime_stop;   // used to exclude text/ mime type from standard e2g phrase scan
 
     private:
     // HTML template - if it overrides the default
@@ -160,7 +163,7 @@ public:
     std::deque<std::string> conffile;
 
     bool precompileregexps();
-    bool readFile(const char *filename, unsigned int *whichlist, bool sortsw, bool cache, const char *listname);
+    bool readFile(const char *filename, const char *list_pwd, unsigned int *whichlist, bool sortsw, bool cache, const char *listname);
     bool compileRegExMatchFile(unsigned int list, std::deque<RegExp> &list_comp,
         std::deque<String> &list_source, std::deque<unsigned int> &list_ref);
     bool readRegExReplacementFile(const char *filename, const char *listname, unsigned int &listid,
