@@ -7,9 +7,9 @@
 
 // DEFINES
 
-#define __DGHEADER_SENDALL 0
-#define __DGHEADER_SENDFIRSTLINE 1
-#define __DGHEADER_SENDREST 2
+#define __E2HEADER_SENDALL 0
+#define __E2HEADER_SENDFIRSTLINE 1
+#define __E2HEADER_SENDREST 2
 
 #define  __HEADER_REQUEST      1
 #define  __HEADER_RESPONSE   2
@@ -35,6 +35,8 @@ class HTTPHeader
     unsigned int port;
     bool is_response = false;
     bool icap;
+    bool first_line_sent = false;
+    bool header_all_sent = false;
     String redirect;
     String useragent;
     String contenttype;
@@ -78,6 +80,7 @@ class HTTPHeader
     // get content length - returns -1 if undetermined
     off_t contentLength();
     String getContentType();
+    bool OKtoFilterMime(FOptionContainer* &foc);
     String getMIMEBoundary();
     // check received content type against given content type
     //bool isContentType(const String &t,int filtergroup);
@@ -164,6 +167,9 @@ class HTTPHeader
     // modifies the URL in all relevant header lines after a regexp search and replace
     // setURL Code originally from from Ton Gorter 2004
     void setURL(String &url);
+
+    // modifies connect site only - leaves other headers alone
+    void setConnect(String &con_site);
     // do URL decoding (%xx) on string
     // decode everything, or just numbers, letters and -
     static String decode(const String &s, bool decodeAll = false);
@@ -171,8 +177,9 @@ class HTTPHeader
     // Bypass URL & Cookie funcs
 
     bool isBypassCookie(String url, const char *magic, const char *clientip, const char *user);
-    void chopBypass(String url, bool infectionbypass);
-    void chopScanBypass(String url);
+    //void chopBypass(String url, bool infectionbypass);
+    void chopBypass(String url,std::string bp_type);
+    //void chopScanBypass(String url);
     // add cookie to outgoing headers with given name & value
     void setCookie(const char *cookie, const char *domain, const char *value);
     bool isProxyRequest;
@@ -209,7 +216,16 @@ class HTTPHeader
             is_response = false;
     };
 
-       private:
+    // generate bypass hashed url
+    String hashedURL(String *url,  std::string *clientip,
+                     bool infectionbypass, std::string *user, FOptionContainer &fdl, bool fakecgi = false);
+    // generate bypass hashed cookie
+    String hashedCookie(String *url, const char *magic, std::string *clientip, int bypasstimestamp, std::string user);
+
+    // base64 decode a complete string
+    std::string decodeb64(const String &line);
+
+private:
         // timeout for socket operations
         int timeout;
 
@@ -263,8 +279,6 @@ class HTTPHeader
     static String hexToChar(const String &n, bool all = false);
     // base64 decode an individual char
     int decode1b64(char c);
-    // base64 decode a complete string
-    std::string decodeb64(const String &line);
 
     // modify supplied accept-encoding header, adding "identity" and stripping unsupported compression types
     String modifyEncodings(String e);
@@ -275,6 +289,7 @@ class HTTPHeader
 
     // grab cookies from headers
     String getCookie(const char *cookie);
+
 };
 
 #endif
