@@ -5,12 +5,13 @@
 // INCLUDES
 
 #ifdef HAVE_CONFIG_H
-#include "dgconfig.h"
+#include "e2config.h"
 #endif
 #include "ICAPHeader.hpp"
 #include "Socket.hpp"
 #include "OptionContainer.hpp"
 #include "FDTunnel.hpp"
+#include "Logger.hpp"
 
 #include <unistd.h>
 #include <sys/socket.h>
@@ -18,13 +19,11 @@
 #include <time.h>
 #include <stdio.h>
 #include <string.h>
-#include <syslog.h>
 #include <cerrno>
 #include <zlib.h>
 
 // GLOBALS
 extern OptionContainer o;
-extern thread_local std::string thread_id;
 
 // IMPLEMENTATION
 
@@ -36,15 +35,7 @@ void ICAPHeader::setTimeout(int t)
 
 bool ICAPHeader::setEncapRecs() {
     String t = *pencapsulated;
-#ifndef NEWDEBUG_OFF
-        if(o.myDebug->ICAP)
-        {
-            std::ostringstream oss (std::ostringstream::out);
-            oss << thread_id << "pencapsulated is " << t << std::endl;
-            o.myDebug->Debug("ICAP",oss.str());
-            std::cerr << thread_id << "pencapsulated is " << t << std::endl;
-        }
-#endif
+    DEBUG_icap("pencapsulated is ", t);
     t = t.after(": ");
     while ( t.length() ) {
         String t1 = t.before(",");
@@ -98,6 +89,8 @@ void ICAPHeader::reset()
         res_hdr_flag = false;
         out_req_hdr_flag = false;
         out_res_hdr_flag = false;
+        out_req_body_flag = false;
+        out_res_body_flag = false;
         req_body_flag = false;
         res_body_flag = false;
         opt_body_flag = false;
@@ -196,16 +189,9 @@ void ICAPHeader::checkheader(bool allowpersistent)
             icap_com.log_mess_no = t.before(",").toInteger();
             icap_com.mess_string = t.after(",");
         }
-#ifndef NEWDEBUG_OFF
-        if(o.myDebug->ICAP)
-        {
-            String t2 = *i;
-            std::ostringstream oss (std::ostringstream::out);
-            oss << thread_id << "Header value from ICAP client: " << t2 <<  "allow_204 is " << allow_204 << " allow_206 is " << allow_206 << std::endl;
-            o.myDebug->Debug("ICAP", oss.str());
-            std::cerr << "Header value from ICAP client: " << t2 <<  "allow_204 is " << allow_204 << " allow_206 is " << allow_206 << std::endl;
-        }
-#endif
+
+        String t2 = *i;
+        DEBUG_icap("Header value from ICAP client: ", t2,  "allow_204 is ", allow_204, " allow_206 is ", allow_206 );
 
         }
     }
@@ -278,15 +264,7 @@ String ICAPHeader::getUrl()
         }
     }
 
-#ifndef NEWDEBUG_OFF
-	if(o.myDebug->ICAP)
-	{
-		std::ostringstream oss (std::ostringstream::out);
-		oss << thread_id << "from header url:" << answer << std::endl;
-		o.myDebug->Debug("ICAP",oss.str());
-		std::cerr << thread_id << "from header url:" << answer << std::endl;
-	}
-#endif
+	DEBUG_icap("from header url:", answer);
 
     return answer;
 }
@@ -343,71 +321,7 @@ String ICAPHeader::hexToChar(const String &n, bool all)
     }
 }
 
-// decode a line of base64
-std::string ICAPHeader::decodeb64(const String &line)
-{ // decode a block of b64 MIME
-    long four = 0;
-    int d;
-    std::string result;
-    int len = line.length() - 4;
-    for (int i = 0; i < len; i += 4) {
-        four = 0;
-        d = decode1b64(line[i + 0]);
-        four = four | d;
-        d = decode1b64(line[i + 1]);
-        four = (four << 6) | d;
-        d = decode1b64(line[i + 2]);
-        four = (four << 6) | d;
-        d = decode1b64(line[i + 3]);
-        four = (four << 6) | d;
-        d = (four & 0xFF0000) >> 16;
-        result += (char)d;
-        d = (four & 0xFF00) >> 8;
-        result += (char)d;
-        d = four & 0xFF;
-        result += (char)d;
-    }
-    return result;
-}
 
-// decode an individual base64 character
-int ICAPHeader::decode1b64(char c)
-{
-    unsigned char i = '\0';
-    switch (c) {
-    case '+':
-        i = 62;
-        break;
-    case '/':
-        i = 63;
-        break;
-    case '=':
-        i = 0;
-        break;
-    default: // must be A-Z, a-z or 0-9
-        i = '9' - c;
-        if (i > 0x3F) { // under 9
-            i = 'Z' - c;
-            if (i > 0x3F) { // over Z
-                i = 'z' - c;
-                if (i > 0x3F) { // over z so invalid
-                    i = 0x80; // so set the high bit
-                } else {
-                    // a-z
-                    i = c - 71;
-                }
-            } else {
-                // A-Z
-                i = c - 65;
-            }
-        } else {
-            // 0-9
-            i = c + 4;
-        }
-        break;
-    }
-    return (int)i;
-}
 
 // *
 // *
@@ -418,28 +332,12 @@ int ICAPHeader::decode1b64(char c)
 // send headers out over the given socket
 bool ICAPHeader::respond(Socket &sock, String res_code, bool echo, bool encap)
 {
-#ifndef NEWDEBUG_OFF
-    if(o.myDebug->ICAP)
-	{
-		std::ostringstream oss (std::ostringstream::out);
-		oss << thread_id << "ICAP response starting - RCode " << res_code << " echo is " << echo << std::endl;
-		o.myDebug->Debug("ICAP",oss.str());
-		std::cerr << thread_id << "ICAP response starting - RCode " << res_code << " echo is " << echo << std::endl;
-	}
-#endif
+	DEBUG_icap("ICAP response starting - RCode ", res_code, " echo is ", echo);
     String l; // for amalgamating to avoid conflict with the Nagel algorithm
     if(echo) {
         if (service_reqmod && !(out_res_hdr_flag || out_req_hdr_flag)) {
             out_req_header = HTTPrequest.stringHeader();
-#ifndef NEWDEBUG_OFF
-            if(o.myDebug->ICAP)
-            {
-                std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "out_req_header copied from HTTPrequest :" << out_req_header << std::endl;
-                o.myDebug->Debug("ICAP",oss.str().c_str());
-                std::cerr << thread_id << "out_req_header copied from HTTPrequest :" << out_req_header << std::endl;
-            }
-#endif
+            DEBUG_icap("out_req_header copied from HTTPrequest :", out_req_header);
             out_req_hdr_flag = true;
             out_req_body_flag = req_body_flag;
             if (req_body > 0)
@@ -448,15 +346,7 @@ bool ICAPHeader::respond(Socket &sock, String res_code, bool echo, bool encap)
 
         if (service_resmod && !(out_res_hdr_flag)) {
             out_res_header = HTTPresponse.stringHeader();
-#ifndef NEWDEBUG_OFF
-            if(o.myDebug->ICAP)
-            {
-                std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "out_res_header is " << out_res_header << std::endl;
-                o.myDebug->Debug("ICAP",oss.str());
-                std::cerr << thread_id << "out_res_header is " << out_res_header << std::endl;
-            }
-#endif
+            DEBUG_icap("out_res_header is ", out_res_header);
             out_res_hdr_flag = true;
             out_res_body_flag = res_body_flag;
             if (res_body > 0) {
@@ -541,29 +431,12 @@ bool ICAPHeader::respond(Socket &sock, String res_code, bool echo, bool encap)
         }
     }
 
-#ifndef NEWDEBUG_OFF
-    if(o.myDebug->ICAP)
-     {
-        	std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "Icap response header is: " << l <<  std::endl;
-                std::cerr << thread_id << "Icap response header is: " << l << std::endl;
-                o.myDebug->Debug("ICAP", oss.str());
-     }
-#endif
+    DEBUG_icap("Icap response header is: ", l);
     if (!sock.writeToSocket(l.toCharArray(), l.length(), 0, timeout)) {
         return false;
     }
 
-
-#ifndef NEWDEBUG_OFF
-	if(o.myDebug->ICAP)
-	{
-		std::ostringstream oss (std::ostringstream::out);
-		oss << thread_id << "Returning from icapheader:respond" <<  std::endl;
-    		std::cerr << thread_id << "Returning from icapheader:respond" << std::endl;
-		o.myDebug->Debug("ICAP", oss.str());
-	}
-#endif
+	DEBUG_icap("Returning from icapheader:respond");
 
     return true;
 }
@@ -578,24 +451,8 @@ bool  ICAPHeader::errorResponse(Socket &peerconn, String &res_header, String &re
         out_res_body_flag = true;
     }
 
-#ifndef NEWDEBUG_OFF
-	if(o.myDebug->ICAP)
-	{
-		std::ostringstream oss (std::ostringstream::out);
-		oss << thread_id << "out_res_header: " << out_res_header <<  std::endl;
-		o.myDebug->Debug("ICAP", oss.str());
-                std::cerr << thread_id << "out_res_header: " << out_res_header << std::endl;
-	}
-#endif
-#ifndef NEWDEBUG_OFF
-        if(o.myDebug->ICAP)
-        {
-		std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "out_res_body: " << out_res_body <<  std::endl;
-                o.myDebug->Debug("ICAP", oss.str());
-                std::cerr << thread_id << "out_res_body: " << out_res_body << std::endl;
-        }
-#endif
+	DEBUG_icap("out_res_header: ",out_res_header);
+    DEBUG_icap("out_res_body: ", out_res_body);
 
 
 
@@ -622,22 +479,12 @@ bool ICAPHeader::in(Socket *sock, bool allowpersistent)
         reset();
     dirty = true;
 
-#ifndef NEWDEBUG_OFF
-	if(o.myDebug->ICAP)
-	{
-		std::ostringstream oss (std::ostringstream::out);
-		if(is_response)
-		{
-			oss << thread_id << "Start of response ICAPheader:in"  << std::endl;
-			std::cerr << thread_id << "Start of response ICAPheader:in"  << std::endl;
-		}
-		else
-		{
-			oss << thread_id << "Start of request ICAPheader:in"  << std::endl;
-			std::cerr << thread_id << "Start of request ICAPheader:in"  << std::endl;
-		}
-		o.myDebug->Debug("ICAP", oss.str());
-	}
+#ifdef DEBUG_HIGH
+    if(is_response) {
+        DEBUG_icap("Start of response ICAPheader:in");
+    } else {
+        DEBUG_icap("Start of request ICAPheader:in");
+    }
 #endif
 
     // the RFCs don't specify a max header line length so this should be
@@ -653,74 +500,34 @@ bool ICAPHeader::in(Socket *sock, bool allowpersistent)
         // get a line of header from the stream
         bool truncated = false;
         int rc;
-        bool honour_reloadconfig = false;  // TEMPORARY FIX!!!!
         if (firsttime) {
 
-#ifndef NEWDEBUG_OFF
-            if(o.myDebug->ICAP)
-            {
-                std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "ICAPheader:in before getLine - timeout: " << timeout  << std::endl;
-                o.myDebug->Debug("ICAP",oss.str());
-                std::cerr << thread_id << "ICAPheader:in before getLine - timeout: " << timeout << std::endl;
-            }
-#endif
+            DEBUG_icap("ICAPheader:in before getLine - timeout: ", timeout);
+
+            rc = sock->getLine(buff, 32768, timeout, NULL, &truncated);
+            DEBUG_icap("firstime: ICAPheader:in after getLine ");
 
-            rc = sock->getLine(buff, 32768, timeout, firsttime ? honour_reloadconfig : false, NULL, &truncated);
-#ifndef NEWDEBUG_OFF
-            if(o.myDebug->ICAP)
-            {
-                std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "firstime: ICAPheader:in after getLine " << std::endl;
-                o.myDebug->Debug("ICAP",oss.str());
-                std::cerr << thread_id << "firstime: ICAPheader:in after getLine "  << std::endl;
-            }
-#endif
             if (rc == 0) return false;
             if (rc < 0 || truncated) {
                 ispersistent = false;
-#ifndef NEWDEBUG_OFF
-                if(o.myDebug->ICAP)
-                {
-                    std::ostringstream oss (std::ostringstream::out);
-                    oss << thread_id << "firstime: ICAPheader:in after getLine: rc: " << rc << " truncated: " << truncated << std::endl;
-                    o.myDebug->Debug("ICAP",oss.str());
-                    std::cerr << thread_id << "firstime: ICAPheader:in after getLine: rc: " << rc << " truncated: " << truncated << std::endl;
-                }
-#endif
+                DEBUG_icap("firstime: ICAPheader:in after getLine: rc: ", rc, " truncated: ", truncated );
                 return false;
             }
         } else {
-            rc = sock->getLine(buff, 32768, timeout, firsttime ? honour_reloadconfig : false, NULL,
+            rc = sock->getLine(buff, 32768, timeout, NULL,
                                &truncated);   // timeout reduced to 100ms for lines after first
             if (rc == 0) return false;
             if (rc < 0 || truncated) {
                 ispersistent = false;
-#ifndef NEWDEBUG_OFF
-                if(o.myDebug->ICAP)
-                {
-                    std::ostringstream oss (std::ostringstream::out);
-                    oss << thread_id << "not firstime: ICAPheader:in after getLine: rc: " << rc << " truncated: " << truncated << std::endl;
-                    o.myDebug->Debug("ICAP",oss.str());
-                    std::cerr << thread_id << "not firstime: ICAPheader:in after getLine: rc: " << rc << " truncated: " << truncated << std::endl;
-                }
-#endif
+                DEBUG_icap("not firstime: ICAPheader:in after getLine: rc: ", rc, " truncated: ", truncated );
                 return false;        // do not allow non-terminated headers
             }
 
         }
 
-        if (header.size() > o.max_header_lines) {
-#ifndef NEWDEBUG_OFF
-            if(o.myDebug->ICAP)
-            {
-                std::ostringstream oss (std::ostringstream::out);
-                oss << thread_id << "ICAP header:size too big =  " << header.size() << std::endl;
-                o.myDebug->Debug("ICAP",oss.str());
-                std::cerr << thread_id << "ICAP header:size too big =  " << header.size() << std::endl;
-            }
-#endif
-	    syslog(LOG_INFO, "%s header:size too big: %lu, see maxheaderlines", thread_id.c_str(), header.size());
+        if (header.size() > o.header.max_header_lines) {
+            DEBUG_icap("ICAP header:size too big =  ", header.size() );
+	        E2LOGGER_info(" header:size too big: ", header.size(),  ", see maxheaderlines");
             ispersistent = false;
             return false;
         }
@@ -738,59 +545,28 @@ bool ICAPHeader::in(Socket *sock, bool allowpersistent)
             if (is_response) {
                 if (!(line.length() > 11 && line.startsWith("ICAP/") &&
                       (line.after(" ").before(" ").toInteger() > 99))) {
-                    if (o.logconerror)
-                        syslog(LOG_INFO, "%sServer did not respond with ICAP", thread_id.c_str());
-#ifndef NEWDEBUG_OFF
-                        if(o.myDebug->ICAP)
-                        {
-                            std::ostringstream oss (std::ostringstream::out);
-                            oss << thread_id << "Returning from header:in Server did not respond with ICAP length: " << line.length() << " content: " << line << std::endl;
-                            o.myDebug->Debug("ICAP",oss.str());
-                            std::cerr << thread_id << "Returning from header:in Server did not respond with ICAP length: " <<  line.length() << " content: " << line << std::endl;
-                        }
-#endif
+                    if (o.conn.logconerror) {
+                        E2LOGGER_error("Server did not respond with ICAP");
+                    }
+                    DEBUG_icap("Returning from header:in Server did not respond with ICAP length: ", line.length(), " content: ", line );
                     return false;
                 }
             } else {
                 method = line.before(" ");
-#ifndef NEWDEBUG_OFF
-                if(o.myDebug->ICAP)
-                {
-                        std::ostringstream oss (std::ostringstream::out);
-                        oss << thread_id << "Returning from header:in client requests with ICAP length: " << line.length() << " content: " << line << std::endl;
-                        o.myDebug->Debug("ICAP",oss.str());
-                        std::cerr << thread_id << "Returning from header:in Client request with ICAP length: " <<  line.length() << " content: " << line << std::endl;
-                }
-#endif
+                DEBUG_icap("Returning from header:in client requests with ICAP length: ", line.length(), " content: ", line);
                 String t = line.after(" ").before(" ");
-#ifndef NEWDEBUG_OFF
-                if(o.myDebug->ICAP)
-                {
-                        std::ostringstream oss (std::ostringstream::out);
-                        oss << thread_id << "Request is " << t << " size: " << line.length() << " content: " << line << std::endl;
-                        o.myDebug->Debug("ICAP",oss.str());
-                        std::cerr << thread_id << "Request is " << t << " size: " << line.length() << " content: " << line << std::endl;
-                }
-#endif
+                DEBUG_icap("Request is ", t, " size: ", line.length(), " content: ", line);
                 if (t.startsWith("icap://")) {
                     // valid protocol
                 } else {
                     icap_error = "400 Bad Request";
-#ifndef NEWDEBUG_OFF
-                   if(o.myDebug->ICAP)
-                   {
-                        std::ostringstream oss (std::ostringstream::out);
-                        oss << thread_id << "Request error is: " << icap_error << " Line: " << t << std::endl;
-                        o.myDebug->Debug("ICAP",oss.str());
-                        std::cerr << thread_id << "Request error is: " << icap_error << std::endl;
-                   }
-#endif
+                    DEBUG_icap("Request error is: ", icap_error, " Line: ", t);
                     return false;
                 }
                 t = t.after("//").after("/");
-                if (t == o.icap_reqmod_url) {
+                if (t == o.icap.icap_reqmod_url) {
                     icap_reqmod_service = true;
-                } else if (t == o.icap_resmod_url) {
+                } else if (t == o.icap.icap_resmod_url) {
                     icap_resmod_service = true;
                 } else {
                     icap_error = "404 ICAP Service not found";
@@ -805,15 +581,7 @@ bool ICAPHeader::in(Socket *sock, bool allowpersistent)
                     icap_error = "405 Method not allowed for service";
                 }
 
-#ifndef NEWDEBUG_OFF
-                if(o.myDebug->ICAP)
-                   {
-                        std::ostringstream oss (std::ostringstream::out);
-                        oss << thread_id << "Request method is: " << method << " error?: " << icap_error << " url value: " << t << std::endl;
-                        o.myDebug->Debug("ICAP",oss.str());
-                        std::cerr << thread_id << "Request method is: " << method << " error?: " << icap_error << " url value: " << t << std::endl;
-                   }
-#endif
+                DEBUG_icap("Request method is: ", method, " error?: ", icap_error, " url value: ", t);
             }
         }
             // ignore crap left in buffer from old pconns (in particular, the IE "extra CRLF after POST" bug)
@@ -822,16 +590,7 @@ bool ICAPHeader::in(Socket *sock, bool allowpersistent)
                 header.push_back(line); // stick the line in the deque that holds the header
             } else {
                 discard = true;
-#ifndef NEWDEBUG_OFF
-                if(o.myDebug->ICAP)
-                {
-                    std::ostringstream oss (std::ostringstream::out);
-                    oss << thread_id << "Discarding unwanted bytes at head of request (pconn closed or IE multipart POST bug)" << std::endl;
-                    o.myDebug->Debug("ICAP",oss.str());
-
-                            std::cerr << thread_id << "Discarding unwanted bytes at head of request (pconn closed or IE multipart POST bug)" << std::endl;
-                }
-#endif
+                DEBUG_icap("Discarding unwanted bytes at head of request (pconn closed or IE multipart POST bug)");
             }
             firsttime = false;
 // End of while
@@ -839,29 +598,13 @@ bool ICAPHeader::in(Socket *sock, bool allowpersistent)
 
 
     if (header.size() == 0) {
-#ifndef NEWDEBUG_OFF
-        if(o.myDebug->ICAP)
-        {
-            std::ostringstream oss (std::ostringstream::out);
-            oss << thread_id << "ICAP header:size = 0 "  << std::endl;
-            o.myDebug->Debug("ICAP",oss.str());
-                std::cerr << thread_id << "ICAP header:size = 0 "  << std::endl;
-        }
-#endif
+        DEBUG_icap("ICAP header:size = 0 ");
         return false;
     }
 
     header.pop_back(); // remove the final blank line of a header
     checkheader(allowpersistent); // sort out a few bits in the header
-#ifndef NEWDEBUG_OFF
-    if(o.myDebug->ICAP)
-    {
-        std::ostringstream oss (std::ostringstream::out);
-        oss << thread_id << "checkheader done- " << encap_recs.size() << " encap_recs" << std::endl;
-        o.myDebug->Debug("ICAP",oss.str());
-            std::cerr << thread_id << "checkheader done- " << encap_recs.size() << " encap_recs" << std::endl;
-    }
-#endif
+    DEBUG_icap("checkheader done- ", encap_recs.size(), " encap_recs");
     //now need to get http req and res headers - if present
     HTTPrequest.reset();
     HTTPresponse.reset();
